==> nextcloud-24.0.9.tgz: nextcloud/apps/comments/l10n/sc.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Cummentos",
    "You commented" : "As cummentadu",
    "{author} commented" : "{author} at cummentadu",
    "You commented on %1$s" : "As cummentadu in %1$s",
    "You commented on {file}" : "As cummentadu {file}",
    "%1$s commented on %2$s" : "%1$s at cummentadu %2$s",
    "{author} commented on {file}" : "{author} at cummentadu {file}",
    "<strong>Comments</strong> for files" : "<strong>Cummentos</strong> pro archìvios",
    "Files app plugin to add comments to files" : "Estensione de s'aplicatzione archìvios pro agiùnghere cummentos a archìvios",
    "Edit comment" : "Modìfica cummentu",
    "Delete comment" : "Cantzella cummentu",
    "Cancel edit" : "Annulla modìfica",
    "Post comment" : "Pùblica cummentu",
    "No comments yet, start the conversation!" : "Ancora perunu cummentu, cumintza sa cunversatzione!",
    "No more messages" : "Perunu àteru messàgiu",
    "Retry" : "Torra a proare",
    "Unable to load the comments list" : "Non faghet a carrigare sa lista de cummentos",
    "_%n unread comment_::_%n unread comments_" : ["%n cummentu non lèghidu","%n cummentos non lèghidos"],
    "_1 new comment_::_{unread} new comments_" : ["1 cummentu nou","{unread} cummentos noos"],
    "Comment" : "Cummenta",
    "An error occurred while trying to edit the comment" : "Ddoe at àpidu un'errore proende a modificare su cummentu",
    "Comment deleted" : "Cummentu cantzelladu",
    "An error occurred while trying to delete the comment" : "B'at àpidu un'errore proende a cantzellare su cummentu",
    "An error occurred while trying to create the comment" : "B'at àpidu un'errore proende a creare su cummentu",
    "%1$s commented" : "%1$s at cummentadu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.12.tgz: nextcloud/apps/comments/l10n/sc.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Cummentos",
    "You commented" : "As cummentadu",
    "{author} commented" : "{author} at cummentadu",
    "You commented on %1$s" : "As cummentadu in %1$s",
    "You commented on {file}" : "As cummentadu {file}",
    "%1$s commented on %2$s" : "%1$s at cummentadu %2$s",
    "{author} commented on {file}" : "{author} at cummentadu {file}",
    "<strong>Comments</strong> for files" : "<strong>Cummentos</strong> pro archìvios",
    "Files app plugin to add comments to files" : "Estensione de s'aplicatzione archìvios pro agiùnghere cummentos a archìvios",
    "Edit comment" : "Modìfica cummentu",
    "Delete comment" : "Cantzella cummentu",
    "Cancel edit" : "Annulla modìfica",
    "Post comment" : "Pùblica cummentu",
    "No comments yet, start the conversation!" : "Ancora perunu cummentu, cumintza sa cunversatzione!",
    "No more messages" : "Perunu àteru messàgiu",
    "Retry" : "Torra a proare",
    "Unable to load the comments list" : "Non faghet a carrigare sa lista de cummentos",
    "_1 new comment_::_{unread} new comments_" : ["1 cummentu nou","{unread} cummentos noos"],
    "Comment" : "Cummenta",
    "An error occurred while trying to edit the comment" : "Ddoe at àpidu un'errore proende a modificare su cummentu",
    "Comment deleted" : "Cummentu cantzelladu",
    "An error occurred while trying to delete the comment" : "B'at àpidu un'errore proende a cantzellare su cummentu",
    "An error occurred while trying to create the comment" : "B'at àpidu un'errore proende a creare su cummentu",
    "%1$s commented" : "%1$s at cummentadu",
    "_%n unread comment_::_%n unread comments_" : ["%n cummentu non lèghidu","%n cummentos non lèghidos"]
},
"nplurals=2; plural=(n != 1);");
